==> pdsh_2.22.orig.tar.bz2: pdsh-2.22/src/pdsh/privsep.h <==
/*****************************************************************************\
 *  $Id: privsep.h 1009 2006-02-14 16:11:43Z grondo $
 *****************************************************************************
 *  Copyright (C) 2001-2006 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Jim Garlick <garlick@llnl.gov>.
 *  UCRL-CODE-2003-005.
 *  
 *  This file is part of Pdsh, a parallel remote shell program.
 *  For details, see <http://www.llnl.gov/linux/pdsh/>.
 *  
 *  Pdsh is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *  
 *  Pdsh is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *  
 *  You should have received a copy of the GNU General Public License along
 *  with Pdsh; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
\*****************************************************************************/
#ifndef _PRIVSEP_H
#define _PRIVSEP_H

/*
 * Initialize privilege separation: fork off privileged child
 *  if we're running setuid.
 */
int privsep_init (void);

/*
 * Close privsep server pipe and reap child.
 */
int privsep_fini (void);

/*
 * Request privilege server to bind to reserved port.
 */
int privsep_rresvport (int *lport);

#endif /* !_PRIVSEP_H */

==> pdsh_2.31.orig.tar.bz2: pdsh-2.31/src/pdsh/privsep.h <==
/*****************************************************************************\
 *  $Id$
 *****************************************************************************
 *  Copyright (C) 2001-2006 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Jim Garlick <garlick@llnl.gov>.
 *  UCRL-CODE-2003-005.
 *  
 *  This file is part of Pdsh, a parallel remote shell program.
 *  For details, see <http://www.llnl.gov/linux/pdsh/>.
 *  
 *  Pdsh is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *  
 *  Pdsh is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *  
 *  You should have received a copy of the GNU General Public License along
 *  with Pdsh; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
\*****************************************************************************/
#ifndef _PRIVSEP_H
#define _PRIVSEP_H

/*
 * Initialize privilege separation: fork off privileged child
 *  if we're running setuid.
 */
int privsep_init (void);

/*
 * Close privsep server pipe and reap child.
 */
int privsep_fini (void);

/*
 * Request privilege server to bind to reserved port.
 */
int privsep_rresvport (int *lport);

/*
 * Request privilege server to bind to reserved port (Including family).
 */
int privsep_rresvport_af (int *lport, int family);

#endif /* !_PRIVSEP_H */
